==> iTop-3.0.3-10998.zip: web/datamodels/2.x/itop-attachments/dictionaries/es_cr.dict.itop-attachments.php <==
<?php
// Copyright (C) 2010-2021 Combodo SARL
//
//   This file is part of iTop.
//
//   iTop is free software; you can redistribute it and/or modify
//   it under the terms of the GNU Affero General Public License as published by
//   the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
//   iTop is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU Affero General Public License for more details.
//
//   You should have received a copy of the GNU Affero General Public License
//   along with iTop. If not, see <http://www.gnu.org/licenses/>
 /**
 * Spanish Localized data
 *
 * @copyright   Copyright (C) 2010-2021 Combodo SARL
 * @license     http://opensource.org/licenses/AGPL-3.0
 * @traductor   Miguel Turrubiates <miguel_tf@yahoo.com>
 */
Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'Attachments:TabTitle_Count' => 'Anexos (%1$d)',
	'Attachments:EmptyTabTitle' => 'Anexos',
	'Attachments:FieldsetTitle' => 'Anexos',
	'Attachments:DeleteBtn' => 'Borrar',
	'Attachments:History_File_Added' => 'Anexo %1$s agregado.',
	'Attachments:History_File_Removed' => 'Anexo %1$s removido.',
	'Attachments:AddAttachment' => 'Agregar Anexo: ',
	'Attachments:UploadNotAllowedOnThisSystem' => 'La carga de archivos NO está permitida en este sistema.',
	'Attachment:Max_Go' => '(Tamaño Máximo de Archivo: %1$s Gb)',
	'Attachment:Max_Mo' => '(Tamaño Máximo de Archivo: %1$s Mb)',
	'Attachment:Max_Ko' => '(Tamaño Máximo de Archivo: %1$s Kb)',
	'Attachments:NoAttachment' => 'No hay Anexo. ',
	'Attachments:PreviewNotAvailable' => 'Vista preliminar no disponible para este tipo de Anexo.',
	'Attachments:Error:FileTooLarge' => 'El archivo es demasiado grande para ser cargado. %1$s',
	'Attachments:Error:UploadedFileEmpty' => 'El archivo recibido está vacío y no puede ser anexado.
Puede ser que haya enviado un archivo vació,
o pregunte al administador de iTop si el servidor que ha quedado sin espacio en disco.',
	'Attachments:Render:Icons' => 'Desplegar como icono',
	'Attachments:Render:Table' => 'Desplegar como lista',
	'UI:Attachments:DropYourFileHint' => 'Arrastre los archivos en cualquier lugar de esta área',
));

//
// Class: Attachment
//

Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'Class:Attachment' => 'Anexo',
	'Class:Attachment+' => 'Anexo',
	'Class:Attachment/Attribute:expire' => 'Expira',
	'Class:Attachment/Attribute:expire+' => '',
	'Class:Attachment/Attribute:temp_id' => 'Id Temporal',
	'Class:Attachment/Attribute:temp_id+' => '',
	'Class:Attachment/Attribute:item_class' => 'Clase de Elemento',
	'Class:Attachment/Attribute:item_class+' => '',
	'Class:Attachment/Attribute:item_id' => 'Elemento',
	'Class:Attachment/Attribute:item_id+' => '',
	'Class:Attachment/Attribute:item_org_id' => 'Organización de Elemento',
	'Class:Attachment/Attribute:item_org_id+' => '',
	'Class:Attachment/Attribute:contents' => 'Contenido',
	'Class:Attachment/Attribute:contents+' => '',
));


Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'Attachments:File:Thumbnail' => 'Ícono',
	'Attachments:File:Name' => 'Nombre de Archivo',
	'Attachments:File:Date' => 'Fecha de Carga',
	'Attachments:File:Uploader' => 'Cargado por',
	'Attachments:File:Size' => 'Tamaño',
	'Attachments:File:MimeType' => 'Tipo',
));
//
// Class: Attachment
//

Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'Class:Attachment/Attribute:creation_date' => 'Fecha de Creación',
	'Class:Attachment/Attribute:creation_date+' => '',
	'Class:Attachment/Attribute:user_id' => 'Id del Usuario',
	'Class:Attachment/Attribute:user_id+' => '',
	'Class:Attachment/Attribute:contact_id' => 'Id del Contacto',
	'Class:Attachment/Attribute:contact_id+' => '',
));

==> iTop-3.1.0-2-11973.zip: web/datamodels/2.x/itop-attachments/dictionaries/es_cr.dict.itop-attachments.php <==
<?php
// Copyright (C) 2010-2023 Combodo SARL
//
//   This file is part of iTop.
//
//   iTop is free software; you can redistribute it and/or modify
//   it under the terms of the GNU Affero General Public License as published by
//   the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
//   iTop is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU Affero General Public License for more details.
//
//   You should have received a copy of the GNU Affero General Public License
//   along with iTop. If not, see <http://www.gnu.org/licenses/>
/**
 * Spanish Localized data
 *
 * @copyright   Copyright (C) 2010-2023 Combodo SARL
 * @license     http://opensource.org/licenses/AGPL-3.0
 * @traductor   Miguel Turrubiates <miguel_tf@yahoo.com>
 */
Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'Attachments:TabTitle_Count' => 'Anexos (%1$d)',
	'Attachments:EmptyTabTitle' => 'Anexos',
	'Attachments:FieldsetTitle' => 'Anexos',
	'Attachments:DeleteBtn' => 'Borrar',
	'Attachments:History_File_Added' => 'Anexo %1$s agregado.',
	'Attachments:History_File_Removed' => 'Anexo %1$s removido.',
	'Attachments:AddAttachment' => 'Agregar Anexo: ',
	'Attachments:UploadNotAllowedOnThisSystem' => 'La carga de archivos NO está permitida en este sistema.',
	'Attachment:Max_Go' => '(Tamaño Máximo de Archivo: %1$s Gb)',
	'Attachment:Max_Mo' => '(Tamaño Máximo de Archivo: %1$s Mb)',
	'Attachment:Max_Ko' => '(Tamaño Máximo de Archivo: %1$s Kb)',
	'Attachments:NoAttachment' => 'No hay Anexo. ',
	'Attachments:PreviewNotAvailable' => 'Vista preliminar no disponible para este tipo de Anexo.',
	'Attachments:Error:FileTooLarge' => 'El archivo es demasiado grande para ser cargado. %1$s',
	'Attachments:Error:UploadedFileEmpty' => 'El archivo recibido está vacío y no puede ser anexado.
Puede ser que haya enviado un archivo vació,
o pregunte al administador de iTop si el servidor que ha quedado sin espacio en disco.',
	'Attachments:Render:Icons' => 'Desplegar como icono',
	'Attachments:Render:Table' => 'Desplegar como lista',
	'UI:Attachments:DropYourFileHint' => 'Arrastre los archivos en cualquier lugar de esta área',
));

//
// Class: Attachment
//

Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'Class:Attachment' => 'Anexo',
	'Class:Attachment+' => 'Anexo',
	'Class:Attachment/Attribute:expire' => 'Expira',
	'Class:Attachment/Attribute:expire+' => '',
	'Class:Attachment/Attribute:temp_id' => 'Id Temporal',
	'Class:Attachment/Attribute:temp_id+' => '',
	'Class:Attachment/Attribute:item_class' => 'Clase de Elemento',
	'Class:Attachment/Attribute:item_class+' => '',
	'Class:Attachment/Attribute:item_id' => 'Elemento',
	'Class:Attachment/Attribute:item_id+' => '',
	'Class:Attachment/Attribute:item_org_id' => 'Organización de Elemento',
	'Class:Attachment/Attribute:item_org_id+' => '',
	'Class:Attachment/Attribute:contents' => 'Contenido',
	'Class:Attachment/Attribute:contents+' => '',
));


Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'Attachments:File:Thumbnail' => 'Ícono',
	'Attachments:File:Name' => 'Nombre de Archivo',
	'Attachments:File:Date' => 'Fecha de Carga',
	'Attachments:File:Uploader' => 'Cargado por',
	'Attachments:File:Size' => 'Tamaño',
	'Attachments:File:MimeType' => 'Tipo',
	'Attachments:File:DownloadsCount' => 'Downloads~~',
));
//
// Class: Attachment
//

Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'Class:Attachment/Attribute:creation_date' => 'Fecha de Creación',
	'Class:Attachment/Attribute:creation_date+' => '',
	'Class:Attachment/Attribute:user_id' => 'Id del Usuario',
	'Class:Attachment/Attribute:user_id+' => '',
	'Class:Attachment/Attribute:contact_id' => 'Id del Contacto',
	'Class:Attachment/Attribute:contact_id+' => '',
));

//
// Class: TriggerOnAttachmentDownload
//

Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'Class:TriggerOnAttachmentDownload' => 'Trigger (on object\'s attachment download)~~',
	'Class:TriggerOnAttachmentDownload+' => 'Trigger on object\'s attachment download of [a child class of] the given class~~',
));
